@@ -3,6 +3,9 @@
 {-# LANGUAGE GADTs #-}
 {-# LANGUAGE TemplateHaskell #-}
 {-# LANGUAGE TypeOperators #-}
+#if defined(__GLASGOW_HASKELL__) && __GLASGOW_HASKELL__ >= 708
+{-# LANGUAGE PolyKinds #-}
+#endif
 module Data.GADT.Compare.TH
     ( DeriveGEQ(..)
     , DeriveGCompare(..)
@@ -93,6 +96,9 @@ instance Monad (GComparing a b) where
     return = GComparing . Right
     GComparing (Left  x) >>= f = GComparing (Left x)
     GComparing (Right x) >>= f = f x
+instance Applicative (GComparing a b) where
+    pure = return
+    (<*>) = ap 
 
 geq' :: GCompare t => t a -> t b -> GComparing x y (a := b)
 geq' x y = GComparing (case gcompare x y of
